@@ -51,16 +51,17 @@ size.title = rel(2),
 size.subtitle = rel(1.5),
 layout = NULL,
 border = NA,
+xlim = NULL,
 ...)
 {
     
     # -- input checks
-    check = check.input.plotLoadings(object = object, block = block, subtitle = subtitle, size.name = size.name, title = title, col = col, name.var = name.var)
+    check = check.input.plotLoadings(object = object, block = block, subtitle = subtitle, size.name = size.name, title = title, col = col, name.var = name.var, xlim = xlim)
     
     col = check$col
     size.name = check$size.name
     block = check$block
-
+    xlim = check$xlim
 
     # -- layout
     res = layout.plotLoadings(layout = layout, plot = TRUE, legend = FALSE, block = block)
@@ -90,7 +91,7 @@ border = NA,
         }
 
         mp = barplot(df$importance, horiz = T, las = 1, col = col, axisnames = TRUE, names.arg = colnames.X, #names.arg = row.names(df),
-        cex.names = size.name, cex.axis = 0.7, beside = TRUE, border = border)
+        cex.names = size.name, cex.axis = 0.7, beside = TRUE, border = border, xlim = xlim[i,])
         
         if ( (length(block) == 1 & is.null(title)) | (length(block) > 1 & missing(subtitle)))
         {
