@@ -769,11 +769,13 @@ print.tune.splsda = function(x, ...)
     "-------------------- \n")
     cat(" Optimal keepX for each component, if 'constraint=FALSE': see object$choice.keepX \n")
     cat(" Optimal keepX.constraint for each component, if 'constraint=TRUE': see object$choice.keepX.constraint \n")
-    cat(" Error rate for each tested keepX and for each component (averaged over the nrepeat): see object$error.rate \n")
+    cat(" Optimal number of components: see object$choice.ncomp \n")    
+    cat(" Error rate for each tested keepX and for each component (averaged over the nrepeat, mean and standard deviation): see object$error.rate and object$error.rate.sd  \n")
     cat(" Error rate for each tested keepX, for each component and for each repeat: see object$error.rate.all \n")
-    cat(" Error rate per class obtained with the optimal keepX, for each component and for each nrepeat: see object$error.rate.class \n\n")
+    cat(" Error rate per class obtained with the optimal keepX, for each component and for each nrepeat: see object$error.rate.class \n")
+    cat(" AUC when applicable, (note that those results may differ with sPLS-DA prediction, see details): see object$AUC \n\n")
     
-    cat(" Other outputs available, see ?tune.splsda.  \n\n")
+    cat(" Other outputs are available, and details on those outputs in ?tune.splsda.  \n\n")
 
     cat(" Visualisation Functions: \n", "-------------------- \n")
     cat(" plot \n")
